summaryrefslogtreecommitdiffstats
path: root/protos
diff options
context:
space:
mode:
authorVadim Tryshev <vadimt@google.com>2018-05-15 14:05:47 -0700
committerVadim Tryshev <vadimt@google.com>2018-05-15 14:58:27 -0700
commitd0788021f9f6d74f49bf5553debf60e5d48895cb (patch)
tree30c987a093d617f42cb957a155c747593ffee4f7 /protos
parent61745e17c75612d97b62313723831e51d62191bf (diff)
downloadandroid_packages_apps_Trebuchet-d0788021f9f6d74f49bf5553debf60e5d48895cb.tar.gz
android_packages_apps_Trebuchet-d0788021f9f6d74f49bf5553debf60e5d48895cb.tar.bz2
android_packages_apps_Trebuchet-d0788021f9f6d74f49bf5553debf60e5d48895cb.zip
Logging Square button presses opening Recents
Examples of traces are in notes. Using the button for closing Recents is not logged. Dooble-tap logs only one entry. Bug: 79437767 Test: logcat Change-Id: Ic2c50ecc937dd2e9cb4b3a7c7439d77bba9b372c
Diffstat (limited to 'protos')
-rw-r--r--protos/launcher_log.proto12
1 files changed, 7 insertions, 5 deletions
diff --git a/protos/launcher_log.proto b/protos/launcher_log.proto
index cd404d6d5..065663dd0 100644
--- a/protos/launcher_log.proto
+++ b/protos/launcher_log.proto
@@ -90,6 +90,7 @@ enum ContainerType {
TASKSWITCHER = 12; // Recents UI Container (QuickStep)
APP = 13; // Foreground activity is another app (QuickStep)
TIP = 14; // Onboarding texts (QuickStep)
+ SIDELOADED_LAUNCHER = 15;
}
// Used to define what type of control a Target would represent.
@@ -148,11 +149,12 @@ message Action {
enum Command {
HOME_INTENT = 0;
BACK = 1;
- ENTRY = 2; // Indicates entry to one of Launcher container type target
- // not using the HOME_INTENT
- CANCEL = 3; // Indicates that a confirmation screen was cancelled
- CONFIRM = 4; // Indicates thata confirmation screen was accepted
- STOP = 5; // Indicates onStop() was called (screen time out, power off)
+ ENTRY = 2; // Indicates entry to one of Launcher container type target
+ // not using the HOME_INTENT
+ CANCEL = 3; // Indicates that a confirmation screen was cancelled
+ CONFIRM = 4; // Indicates thata confirmation screen was accepted
+ STOP = 5; // Indicates onStop() was called (screen time out, power off)
+ RECENTS_BUTTON = 6; // Indicates that Recents button was pressed
}
optional Type type = 1;